<?php

namespace App\Http\Controllers;

use App\Models\Iglesia;
use App\Models\Regional;
use Illuminate\Http\Request;

class IglesiaController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        // Obtener los parámetros de búsqueda y filtro
        $nombre = $request->get('nombre');
        $regional_id = $request->get('regional_id');
    
        // Consultar iglesias, aplicando los filtros según correspondan
        $query = Iglesia::query();
    
        if ($nombre) {
            $query->where('nombre', 'like', '%' . $nombre . '%');
        }
    
        if ($regional_id) {
            $query->where('regional_id', $regional_id);
        }
    
        $iglesias = $query->paginate(5);
    
        // Obtener las regionales activas para el filtro
        $regionales = Regional::where('estado', 1)->get();
    
        return view('iglesias.index', compact('iglesias', 'regionales', 'nombre', 'regional_id'));
    }
    

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $regionales = Regional::where('estado', 1)->get(); // Obtener regionales activas
        return view('iglesias.create', compact('regionales'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
{
    $request->validate([
        'nombre' => 'required|regex:/^[\pL\s]+$/u|max:255',
        'ubicacion' => 'required|regex:/^[\pL\d\s\#\.]+$/u|max:255',
        'regional_id' => 'required|exists:regionales,id'
    ], [
        'nombre.required' => 'El nombre es obligatorio.',
        'nombre.regex' => 'El nombre solo puede contener letras y espacios.',
        'nombre.max' => 'El nombre no puede tener más de 255 caracteres.',
        
        'ubicacion.required' => 'La ubicación es obligatoria.',
        'ubicacion.regex' => 'La ubicación solo puede contener letras, números, espacios, # y .',
        'ubicacion.max' => 'La ubicación no puede tener más de 255 caracteres.',
        
        'regional_id.required' => 'La región es obligatoria.',
        'regional_id.exists' => 'La región seleccionada no existe en el sistema.',
    ]);
 // Aplicar formato a nombre y ubicación
        $nombre = ucwords(strtolower($request->input('nombre'))); // Cada palabra en mayúscula
        $ubicacion = ucfirst(strtolower($request->input('ubicacion'))); // Primera letra en mayúscula
    

    Iglesia::create($request->all());

    return redirect()->route('iglesias.index')->with('success', 'Iglesia creada exitosamente.');
}


    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Iglesia  $iglesia
     * @return \Illuminate\Http\Response
     */
    public function edit(Iglesia $iglesia)
    {
        $regionales = Regional::where('estado', 1)->get();
        return view('iglesias.edit', compact('iglesia', 'regionales'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Iglesia  $iglesia
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Iglesia $iglesia)
    {
        $request->validate([
            'nombre' => 'required|regex:/^[\pL\s]+$/u|max:255',
            'ubicacion' => 'required|regex:/^[\pL\d\s\#\.]+$/u|max:255',
            'regional_id' => 'required|exists:regionales,id'
        ]);
           // Aplicar formato a nombre y ubicación
    $nombre = ucwords(strtolower($request->input('nombre'))); // Cada palabra en mayúscula
    $ubicacion = ucfirst(strtolower($request->input('ubicacion'))); // Primera letra en mayúscula


        $iglesia->update($request->all());

        return redirect()->route('iglesias.index')->with('success', 'Iglesia actualizada exitosamente.');
    }

    /**
     * Remove the specified resource from storage (soft delete).
     *
     * @param  \App\Models\Iglesia  $iglesia
     * @return \Illuminate\Http\Response
     */
    public function destroy(Iglesia $iglesia)
    {
        $iglesia->estado = !$iglesia->estado;
        $iglesia->save();

        return redirect()->route('iglesias.index')->with('success', 'Estado de la iglesia actualizado exitosamente.');
    }
}
