<?php

namespace App\Http\Controllers;

use App\Models\Regional;
use Illuminate\Http\Request;

class RegionalController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index()
    {
        $regionales = Regional::all();
        return view('regionales.index', compact('regionales'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('regionales.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'nombre' => 'required|regex:/^[\pL\s]+$/u|max:255',
            'telefono' => 'nullable|regex:/^\d{8}$/',
        ]);
    
        Regional::create($request->all());
    
        return redirect()->route('regionales.index')->with('success', 'Regional creada exitosamente.');
    }
    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Regional  $regional
     * @return \Illuminate\Http\Response
     */
    public function edit(Regional $regionale)
    {
        return view('regionales.edit', compact('regionale'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Regional  $regional
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Regional $regionale)
    {
        $request->validate([
            'nombre' => 'required|regex:/^[\pL\s]+$/u|max:255',
            'telefono' => 'nullable|regex:/^\d{8}$/',
        ]);
    
        $regionale->update($request->all());
    
        return redirect()->route('regionales.index')->with('success', 'Regional actualizada exitosamente.');
    }
    /**
     * Remove the specified resource from storage (toggle status).
     *
     * @param  \App\Models\Regional  $regional
     * @return \Illuminate\Http\Response
     */
    public function destroy(Regional $regionale)
    {
        // Cambiar el estado de 1 a 0 y de 0 a 1
        $regionale->estado = !$regionale->estado;
        $regionale->save();
    
        return redirect()->route('regionales.index')->with('success', 'Estado de la regional actualizado exitosamente.');
    }
    
}
