@extends('layouts.app')

@section('content')

    <h3 style="color: #eeeff4;">Listado de Miembros</h3>
    
        <div class="section-body">
            <div class="row">
                <div class="col-lg-12">
                    <div class="card">
                        <div class="card-body">

    <!-- Botón de agregar miembro con icono -->
    <a href="{{ route('miembros.create') }}" class="btn btn-primary mb-3">
        <i class="fas fa-user-plus"></i> <!-- Icono de agregar usuario -->
    </a>

    <!-- Mensajes de éxito -->
    @if ($message = Session::get('success'))
        <div class="alert alert-success">
            {{ $message }}
        </div>
    @endif

    <!-- Mensajes de notificación -->
    @if ($notificacion = Session::get('notificacion'))
        <div class="alert alert-success">
            {{ $notificacion }}
        </div>
    @endif

    <!-- Mensajes de error por usuario existente -->
    @if ($error = Session::get('error'))
        <div class="alert alert-danger">
            {{ $error }}
        </div>
    @endif

    <!-- Formulario de búsqueda y filtro -->
    <form action="{{ route('miembros.index') }}" method="GET" class="mb-4">
        <div class="row">
            <div class="col-md-6">
                <input type="text" name="search" class="form-control" placeholder="Buscar por nombre, apellidos, carnet o correo" value="{{ request('search') }}">
            </div>
            <div class="col-md-4">
                <select name="iglesia_id" class="form-control select2" id="iglesia_id" style="width: 100%;">
                    <option value="">Filtrar por Iglesia</option>
                    @foreach ($iglesias as $iglesia)
                        <option value="{{ $iglesia->id }}" 
                            {{ request('iglesia_id') == $iglesia->id ? 'selected' : '' }}>
                            {{ $iglesia->nombre }} - {{ $iglesia->regional->nombre ?? 'Sin regional' }}
                        </option>
                    @endforeach
                </select>
            </div>
            <div class="col-md-2">
                <button type="submit" class="btn btn-primary">
                    <i class="fas fa-search"></i> <!-- Icono de búsqueda -->
                </button>
                <a href="{{ route('miembros.index') }}" class="btn btn-secondary">
                    <i class="fas fa-times"></i> <!-- Icono de limpiar -->
                </a>
            </div>
        </div>
    </form>

    <!-- Tabla responsiva de miembros -->
    <div class="table-responsive">
        <table class="table table-striped mt-2">
            <thead style="background-color:#2f2bec">
                <tr>
                    <th style="color:#fff">Nombre</th>
                    <th style="color:#fff">Apellidos</th>
                    <th style="color:#fff">Carnet</th>
                    <th style="color:#fff">Teléfono</th>
                    <th style="color:#fff">Correo</th>
                    <th style="color:#fff">Iglesia</th>
                    <th style="color:#fff">Regional</th>
                    <th style="color:#fff">Fecha de Nacimiento</th>
                    <th style="color:#fff">Edad</th>
                    <th style="color:#fff">Estado</th>
                    <th style="color:#fff">Acciones</th>
                </tr>
            </thead>
            <tbody>
                @forelse ($miembros as $miembro)
                    <tr>
                        <td>{{ $miembro->nombre }}</td>
                        <td>{{ $miembro->apellidos }}</td>
                        <td>
                            {{ $miembro->carnet }}
                            @if($miembro->complemento)
                                <strong>Complemento:</strong> -{{ $miembro->complemento }}
                            @endif
                            <strong>Extensión:</strong> {{ $miembro->extension }}
                        </td>
                        <td>{{ $miembro->telefono }}</td>
                        <td>{{ $miembro->correo }}</td>
                        <td>{{ $miembro->iglesia->nombre ?? 'Sin asignar' }}</td>
                        <td>{{ $miembro->iglesia->regional->nombre ?? 'Sin regional' }}</td>
                        <td>{{ $miembro->fecha_de_nacimiento }}</td>
                        <td>
                            @php
                                $edad = \Carbon\Carbon::parse($miembro->fecha_de_nacimiento)->age;
                            @endphp
                            {{ $edad }} años
                        </td>
                        <td>{{ $miembro->estado ? 'Activo' : 'Inactivo' }}</td>
                        <td>
                            <!-- Botón de editar -->
                            <a href="{{ route('miembros.edit', $miembro->id) }}" class="btn btn-warning btn-sm">
                                <i class="fas fa-edit"></i> <!-- Icono de edición -->
                            </a>
                            <!-- Botón de activar/desactivar -->
                            <form action="{{ route('miembros.destroy', $miembro->id) }}" method="POST" style="display:inline;">
                                @csrf
                                @method('DELETE')
                                <button type="submit" class="btn btn-danger btn-sm">
                                    <i class="fas {{ $miembro->estado ? 'fa-ban' : 'fa-check-circle' }}"></i> <!-- Icono de activar/desactivar -->
                                </button>
                            </form>
                            <!-- Botón de generar usuario -->
                            <form action="{{ route('miembros.generateUserForm', $miembro->id) }}" method="get" style="display:inline;">
                                @csrf
                                <button type="submit" class="btn btn-success btn-sm">
                                    <i class="fas fa-user-cog"></i> <!-- Icono de generar usuario -->
                                </button>
                            </form>
                        </td>
                    </tr>
                @empty
                    <tr>
                        <td colspan="11" class="text-center">No se encontraron resultados.</td>
                    </tr>
                @endforelse
            </tbody>
        </table>
        {{ $miembros->links() }}
    </div>
</div>
</div>
</div>
</div>
</div>
<!-- Incluir Select2 -->
<link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-beta.1/dist/css/select2.min.css" rel="stylesheet" />
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-beta.1/dist/js/select2.min.js"></script>
<script>
    $(document).ready(function() {
        $('.select2').select2({
            placeholder: 'Seleccione una opción',
            allowClear: true
        });
    });
</script>
@endsection
