@extends('layouts.app')

@section('content')
<div class="container">
    <h3 class="text-center" style="color: #eeeff4;">Registrar Pago para Certificado de {{ ucfirst($certificado->tipo) }}</h3>
    
    <!-- Información del Certificado -->
    <div class="card mb-4">
        <div class="card-header">
            <h5>Información del Certificado</h5>
        </div>
        <div class="card-body">
            @if ($certificado->tipo === 'bautismo')
                <p><strong>Hermano(a):</strong> {{ $certificado->miembro->nombre ?? 'N/A' }}</p>
                <p><strong>Iglesia:</strong> {{ $certificado->iglesia->nombre ?? 'N/A' }}</p>
                <p><strong>Número:</strong> {{ $certificado->numero }}</p>
            @elseif ($certificado->tipo === 'matrimonio')
                @if($certificado->senorMiembro)
                    <p><strong>Señor (miembro):</strong> {{ $certificado->senorMiembro->nombre }} {{ $certificado->senorMiembro->apellidos }}</p>
                @elseif($certificado->senor)
                    <p><strong>Señor:</strong> {{ $certificado->senor }}</p>
                @endif
                
                @if($certificado->senoraMiembro)
                    <p><strong>Señora (miembro):</strong> {{ $certificado->senoraMiembro->nombre }} {{ $certificado->senoraMiembro->apellidos }}</p>
                @elseif($certificado->senora)
                    <p><strong>Señora:</strong> {{ $certificado->senora }}</p>
                @endif
                <p><strong>Notaría N°:</strong> {{ $certificado->notaria_numero }}</p>
                <p><strong>Fecha Matrimonio:</strong> {{ $certificado->fecha_matrimonio ? \Carbon\Carbon::parse($certificado->fecha_matrimonio)->format('d/m/Y') : '-' }}</p>
                <p><strong>N° Libro:</strong> {{ $certificado->libro_numero }}</p>
                <p><strong>Folio:</strong> {{ $certificado->folio }}</p>
                <p><strong>Iglesia:</strong> {{ $certificado->iglesia->nombre ?? 'N/A' }}</p>
                <p><strong>Certificado N°:</strong> {{ $certificado->numero }}</p>
            @elseif ($certificado->tipo === 'consagracion')
                <p><strong>Niño(a):</strong> {{ $certificado->miembro->nombre ?? 'N/A' }}</p>
                <p><strong>Padre:</strong> {{ $certificado->padre }}</p>
                <p><strong>Madre:</strong> {{ $certificado->madre }}</p>
                <p><strong>N° Folio:</strong> {{ $certificado->folio }}</p>
                <p><strong>Número:</strong> {{ $certificado->numero }}</p>
                <p><strong>Iglesia:</strong> {{ $certificado->iglesia->nombre ?? 'N/A' }}</p>
                <p><strong>Fecha:</strong> {{ $certificado->fecha ? \Carbon\Carbon::parse($certificado->fecha)->format('d/m/Y') : '-' }}</p>
            @endif
        </div>
    </div>

    <!-- Verificación del estado del pago -->
    @if ($pagos && $pagos->last() && $pagos->last()->estado === 'completo')
        <div class="alert alert-success">
            El pago ya ha sido realizado. No se requieren más pagos.
        </div>
    @else
        <!-- Formulario de Pago -->
        <form action="{{ route('pagos.store') }}" method="POST">
            @csrf
            <input type="hidden" name="certificado_id" value="{{ $certificado->id }}">
            <input type="hidden" name="fecha_de_pago" value="{{ now()->format('Y-m-d\TH:i') }}">

            <!-- Opciones de Tipo de Pago -->
            <div class="form-group">
                <label>Seleccione el Tipo de Pago:</label>
                <div class="form-check">
                    <input class="form-check-input tipo-pago" type="radio" name="tipo" id="tipo_qr" value="qr">
                    <label class="form-check-label" for="tipo_qr">
                        QR
                    </label>
                </div>
                <div class="form-check">
                    <input class="form-check-input tipo-pago" type="radio" name="tipo" id="tipo_efectivo" value="efectivo">
                    <label class="form-check-label" for="tipo_efectivo">
                        Efectivo
                    </label>
                </div>
            </div>

            <!-- Imagen QR (Condicional) -->
            <div id="qr_section" style="display: none;">
                @if($qr && $qr->fotoqr)
                    <div class="text-center my-4">
                        <img src="{{ asset('storage/' . $qr->fotoqr) }}" alt="QR Code" style="width: 150px; cursor: pointer;" data-toggle="modal" data-target="#qrModal">
                    </div>

                    <!-- Modal -->
                    <div class="modal fade" id="qrModal" tabindex="-1" aria-labelledby="qrModalLabel" aria-hidden="true">
                        <div class="modal-dialog modal-dialog-centered">
                            <div class="modal-content">
                                <div class="modal-body text-center">
                                    <img src="{{ asset('storage/' . $qr->fotoqr) }}" alt="QR Code" style="width: 300px;">
                                </div>
                                <div class="modal-footer">
                                    <button type="button" class="btn btn-danger" data-dismiss="modal">Cerrar</button>
                                </div>
                            </div>
                        </div>
                    </div>
                @else
                    <div class="alert alert-warning text-center">
                        No hay un QR activo disponible.
                    </div>
                @endif
            </div>

            <!-- Monto Total -->
            <div class="form-group">
                <label for="monto_a_pagar">Monto a Pagar</label>
                <input type="number" id="monto_a_pagar" name="monto_a_pagar" class="form-control" value="{{ $certificado->tipo === 'matrimonio' ? 100 : 30 }}" readonly>
            </div>

            <button type="submit" class="btn btn-success">Registrar Pago</button>
            <a href="{{ route('certificados.index') }}" class="btn btn-danger">Cancelar</a>
        </form>
    @endif
</div>
@endsection

@section('scripts')
<script>
    document.addEventListener('DOMContentLoaded', function () {
        // Escuchar cambios en los checkboxes
        const tipoQR = document.getElementById('tipo_qr');
        const tipoEfectivo = document.getElementById('tipo_efectivo');
        const qrSection = document.getElementById('qr_section');

        tipoQR.addEventListener('change', function () {
            if (tipoQR.checked) {
                qrSection.style.display = 'block';
            }
        });

        tipoEfectivo.addEventListener('change', function () {
            if (tipoEfectivo.checked) {
                qrSection.style.display = 'none';
            }
        });
    });
</script>
@endsection
