@extends('layouts.app')

@section('content')

    <h3 class="text-center" style="color: #eeeff4;">Listado de Secretarios</h3>
     <div class="section-body">
        <div class="row">
            <div class="col-lg-12">
                <div class="card">
                    <div class="card-body">
    <a href="{{ route('secretarios.create') }}" class="btn btn-primary mb-3">
        <i class="fas fa-user-plus"></i> <!-- Icono de agregar usuario -->
    </a>

    <!-- Mensajes de éxito -->
    @if ($message = Session::get('success'))
        <div class="alert alert-success">
            {{ $message }}
        </div>
    @endif
 
    <!-- Formulario de búsqueda y filtro -->
    <form action="{{ route('secretarios.index') }}" method="GET" class="mb-4">
        <div class="row">
            <div class="col-md-6">
                <input type="text" name="search" class="form-control" placeholder="Buscar por nombre, apellidos, carnet o correo" value="{{ request('search') }}">
            </div>
            <div class="col-md-4">
                <select name="iglesia_id" class="form-control select2" id="iglesia_id" style="width: 100%;">
                    <option value="">Filtrar por Iglesia</option>
                    @foreach ($iglesias as $iglesia)
                        <option value="{{ $iglesia->id }}" 
                            {{ request('iglesia_id') == $iglesia->id ? 'selected' : '' }}>
                            {{ $iglesia->nombre }} - {{ $iglesia->regional->nombre ?? 'Sin regional' }}
                        </option>
                    @endforeach
                </select>
            </div>
            <div class="col-md-2">
                <button type="submit" class="btn btn-primary">
                    <i class="fas fa-search"></i> <!-- Icono de búsqueda -->
                </button>
                <a href="{{ route('secretarios.index') }}" class="btn btn-secondary">
                    <i class="fas fa-times"></i> <!-- Icono de limpiar -->
                </a>
            </div>
        </div>
    </form>

    <!-- Tabla responsiva -->
    <div class="table-responsive">
        <table class="table table-striped table-hover">
            <thead class="thead-dark" style="background-color:#2f2bec">
                <tr>
                    <th style="color:#fff">Nombre</th>
                    <th style="color:#fff">Apellidos</th>
                    <th style="color:#fff">Carnet</th>
                    <th style="color:#fff">Teléfono</th>
                    <th style="color:#fff">Correo</th>
                    <th style="color:#fff">Iglesia</th>
                    <th style="color:#fff">Regional</th>
                    <th style="color:#fff">Fecha de Nacimiento</th>
                    <th style="color:#fff">Edad</th>
                    <th style="color:#fff">Estado</th>
                    <th style="color:#fff">Acciones</th>
                </tr>
            </thead>
            <tbody>
                @forelse ($secretarios as $secretario)
                    <tr>
                        <td>{{ $secretario->nombre }}</td>
                        <td>{{ $secretario->apellidos }}</td>
                        <td>{{ $secretario->carnet }}</td>
                        <td>{{ $secretario->telefono }}</td>
                        <td>{{ $secretario->correo }}</td>
                        <td>{{ $secretario->iglesia->nombre ?? 'Sin asignar' }}</td>
                        <td>{{ $secretario->iglesia->regional->nombre ?? 'Sin regional' }}</td>
                        <td>{{ $secretario->fecha_de_nacimiento }}</td>
                        <td>
                            @php
                                $edad = \Carbon\Carbon::parse($secretario->fecha_de_nacimiento)->age;
                            @endphp
                            {{ $edad }} años
                        </td>
                        <td>{{ $secretario->estado ? 'Activo' : 'Inactivo' }}</td>
                        <td>
                            <!-- Botón de Editar -->
                            <a href="{{ route('secretarios.edit', $secretario->id) }}" class="btn btn-warning btn-sm">
                                <i class="fas fa-edit"></i>
                            </a>
                            <!-- Botón de Activar/Desactivar -->
                            <form action="{{ route('secretarios.destroy', $secretario->id) }}" method="POST" style="display:inline;">
                                @csrf
                                @method('DELETE')
                                <button type="submit" class="btn btn-danger btn-sm">
                                    <i class="fas {{ $secretario->estado ? 'fa-ban' : 'fa-check-circle' }}"></i>
                                </button>
                            </form>
                            <!-- Botón de Generar Usuario -->
                            <form action="{{ route('secretarios.generateUserForm', $secretario->id) }}" method="get" style="display:inline;">
                                @csrf
                                <button type="submit" class="btn btn-success btn-sm">
                                    <i class="fas fa-user-cog"></i>
                                </button>
                            </form>
                        </td>
                    </tr>
                @empty
                    <tr>
                        <td colspan="11" class="text-center">No se encontraron resultados.</td>
                    </tr>
                @endforelse
            </tbody>
        </table>
        {{ $secretarios->links() }}
    </div>
</div>
</div>
</div>
</div>

</div>
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">

<!-- Incluir Select2 -->
<link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-beta.1/dist/css/select2.min.css" rel="stylesheet" />
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-beta.1/dist/js/select2.min.js"></script>
<script>
    $(document).ready(function() {
        $('.select2').select2({
            placeholder: 'Seleccione una opción',
            allowClear: true
        });
    });
</script>
@endsection
