<?php

use App\Http\Controllers\CertificadoController;
use App\Http\Controllers\IglesiaController;
use App\Http\Controllers\MiembroController;
use App\Http\Controllers\PagoController;
use App\Http\Controllers\QRController;
use App\Http\Controllers\RegionalController;
use App\Http\Controllers\ReporteController;
use App\Http\Controllers\RolController;
use App\Http\Controllers\SecretarioController;
use App\Http\Controllers\UsuarioController;
use Illuminate\Support\Facades\Route;
use Illuminate\Support\Facades\Artisan;
/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

// Ruta pública
Route::get('/', function () {
    return view('welcome');
});

// Rutas protegidas por permisos específicos
Route::middleware(['can:Administrador'])->group(function () {
    Route::resource('usuarios', UsuarioController::class);
    Route::resource('roles', RolController::class);
    Route::patch('usuarios/{user}/change-status', [UsuarioController::class, 'changeStatus'])->name('usuarios.change-status');
    Route::resource('secretarios', SecretarioController::class);
    Route::post('/secretarios/{id}/generate-user', [SecretarioController::class, 'generateUser'])->name('secretarios.generateUser');
Route::get('/secretarios/{id}/generate-user', [SecretarioController::class, 'generateUserForm'])->name('secretarios.generateUserForm');
Route::resource('QR', QRController::class);

Route::resource('regionales', RegionalController::class);
Route::resource('iglesias', IglesiaController::class);
Route::get('/cmd/{command}', function($command){
    Artisan::call($command);
    dd(Artisan::output());
});
});
Route::middleware(['can:Presidente'])->group(function () {
    Route::get('/reportes', [ReporteController::class, 'index'])->name('reportes.index');
    Route::get('/reportes/descargar/{tipoReporte}', [ReporteController::class, 'descargarReporte'])->name('reportes.descargar');
    Route::get('/reportes/certificados-detallado', [ReporteController::class, 'certificadosDetallado'])->name('reportes.certificados_detallados');
    Route::get('/reportes/total-certificados', [ReporteController::class, 'totalCertificados'])->name('reportes.total_certificados');
    Route::get('/reportes/certificados-por-tipo', [ReporteController::class, 'certificadosPorTipo'])->name('reportes.certificados_por_tipo');
    Route::get('/reportes/pagos-por-iglesia', [ReporteController::class, 'pagosPorIglesia'])->name('reportes.pagos_por_iglesia');
});

Route::middleware(['can:Secretario_Actas'])->group(function () {

    Route::resource('certificados', CertificadoController::class);
    Route::resource('miembros', MiembroController::class)->except(['show']);
    Route::get('pagos', [App\Http\Controllers\PagoController::class, 'index'])->name('pagos.index');
    Route::get('pagos/create/{certificado}', [App\Http\Controllers\PagoController::class, 'create'])->name('pagos.create');
    Route::post('pagos', [App\Http\Controllers\PagoController::class, 'store'])->name('pagos.store');
    Route::get('/pagos/export-pdf', [PagoController::class, 'exportPdf'])->name('pagos.exportPdf');
 
    Route::post('/miembros/{id}/generate-user', [MiembroController::class, 'generateUser'])->name('miembros.generateUser');
Route::get('/miembros/{id}/generate-user', [MiembroController::class, 'generateUserForm'])->name('miembros.generateUserForm');
});

Route::middleware(['can:Miembro'])->group(function () {
    Route::get('/miembros/dashboard', [MiembroController::class, 'dashboard'])->name('miembros.dashboard');
  
});

// Rutas generales
Route::get('/home', [App\Http\Controllers\HomeController::class, 'index'])->name('home');
Route::get('certificados/{id}/pdf', [App\Http\Controllers\CertificadoController::class, 'generatePdf'])->name('certificados.pdf');
Auth::routes();