<?php

namespace App\Http\Controllers;

use App\Models\Certificado;
use App\Models\Pago;
use Illuminate\Http\Request;
use Carbon\Carbon;

class HomeController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */
    public function index(Request $request)
    {
        // Obtener el usuario autenticado
        $user = auth()->user();

        // Filtro de fechas
        $startDate = $request->input('start_date', Carbon::now()->startOfYear()->toDateString());
        $endDate = $request->input('end_date', Carbon::now()->endOfYear()->toDateString());

        // Cantidad de certificados por tipo
        $certificadosPorTipo = Certificado::select('tipo', \DB::raw('count(*) as total'))
            ->whereBetween('created_at', [$startDate, $endDate])
            ->groupBy('tipo')
            ->get();

        // Total pagado por tipo de certificado
        $totalPagadoPorTipo = Pago::select('certificados.tipo', \DB::raw('SUM(pagos.monto_pagado) as total_pagado'))
            ->join('certificados', 'pagos.certificado_id', '=', 'certificados.id')
            ->whereBetween('pagos.fecha_de_pago', [$startDate, $endDate])
            ->groupBy('certificados.tipo')
            ->get();

        return view('home', compact('user', 'certificadosPorTipo', 'totalPagadoPorTipo', 'startDate', 'endDate'));
    }
}
