<?php
namespace App\Http\Controllers;

use App\Models\QR;
use Illuminate\Http\Request;

class QRController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index()
    {
        $QR = QR::all();
        return view('QR.index', compact('QR'));
    }

    public function create()
    {
        return view('QR.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'fecha' => 'required|date',
            'fechav' => 'required|date|after_or_equal:fecha', // La fecha de vencimiento debe ser posterior o igual a la fecha del QR
            'fotoqr' => 'image|mimes:jpeg,png,jpg,gif|max:2048', // Validación de imagen (opcional)
        ], [
            'fechav.after_or_equal' => 'La fecha de vencimiento no puede ser anterior a la fecha del QR.',
        ]);
        

        $QR = new QR();
        $QR->fecha = $request->fecha;
        $QR->fechav = $request->fechav;
        $QR->estado = 1; // Establecemos el estado por defecto como 1 (activo)

        if ($request->hasFile('fotoqr')) {
            $imagePath = $request->file('fotoqr')->store('QR_images', 'public');
            $QR->fotoqr = $imagePath;
        }

        $QR->save();

        return redirect()->route('QR.index')->with('success', 'QR creado exitosamente.');
    }

    public function edit(QR $QR)
    {
        return view('QR.edit', compact('QR'));
    }

    public function update(Request $request, QR $QR)
    {
        $request->validate([
            'fecha' => 'required|date',
            'fechav' => 'required|date',
            'fotoqr' => 'image|mimes:jpeg,png,jpg,gif|max:2048',
        ]);

        $QR->fecha = $request->fecha;
        $QR->fechav = $request->fechav;
        if ($request->hasFile('fotoqr')) {
            $imagePath = $request->file('fotoqr')->store('QR_images', 'public');
            $QR->fotoqr = $imagePath;
        }

        $QR->save();

        return redirect()->route('QR.index')->with('success', 'QR actualizado exitosamente.');
    }

    public function destroy(QR $QR)
    {
        $QR->estado = 0; // Cambiamos el estado a 0 (inactivo)
        $QR->save();

        return redirect()->route('QR.index')->with('success', 'QR eliminado exitosamente.');
    }
}
