<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Certificado extends Model
{
    use HasFactory;

    // Definir la tabla asociada (si no sigue la convención de nombres)
    protected $table = 'certificados';

    // Definir los campos asignables en masa
    protected $fillable = [
        'tipo', 
        'miembro_id', 
        'iglesia_id', 
        'numero', 
        'folio', 
        'otorgado', 
        'lugar', 
        'fecha', 
        'senor', 
        'senora', 
        'notaria_numero', 
        'libro_numero', 
        'fecha_matrimonio', 
        'padre', 
        'madre',
        'miembro_senor_id', // Añadido
        'miembro_senora_id'  // Añadido
    ];

    /**
     * Relación con el modelo Miembro (opcional).
     * Un certificado puede estar relacionado con un miembro.
     */
    public function miembro()
    {
        return $this->belongsTo(Miembro::class, 'miembro_id');
    }
// En el modelo Certificado.php
public function pagos()
{
    return $this->hasMany(Pago::class);
}

    /**
     * Relación con el modelo Iglesia (opcional).
     * Un certificado puede estar relacionado con una iglesia.
     */
    public function iglesia()
    {
        return $this->belongsTo(Iglesia::class);
    }

    // Relación con el Señor (miembro)
    public function senorMiembro()
    {
        return $this->belongsTo(Miembro::class, 'miembro_senor_id');
    }

    // Relación con el miembro que es señora en el certificado de matrimonio
    public function senoraMiembro()
    {
        return $this->belongsTo(Miembro::class, 'miembro_senora_id');
    }
    public function pagoCompleto()
{
    // Verificamos si el último pago registrado tiene el estado 'completo'
    return $this->pagos()->where('estado', 'completo')->exists();
}
}
