@extends('layouts.app')

@section('content')
<div class="container">
    <h3 class="text-center" style="color: #eeeff4;">Listado de Certificados</h3>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">

    <!-- Botón de registrar certificado con icono -->
    <a href="{{ route('certificados.create') }}" class="btn btn-primary mb-3">
        <i class="fas fa-file-alt"></i> <!-- Icono de archivo nuevo -->
    </a>

    @if ($message = Session::get('success'))
    <div class="alert alert-success">
        {{ $message }}
    </div>
    @endif

    <!-- Formulario de búsqueda y filtrado -->
    <form action="{{ route('certificados.index') }}" method="GET" class="mb-4">
        <div class="row">
            <div class="col-md-3">
                <input type="text" name="numero" class="form-control" placeholder="Buscar por número" value="{{ request('numero') }}">
            </div>
            <div class="col-md-3">
                <input type="text" name="folio" class="form-control" placeholder="Buscar por folio" value="{{ request('folio') }}">
            </div>
            <div class="col-md-3">
                <select name="tipo" class="form-control">
                    <option value="">Filtrar por tipo</option>
                    <option value="bautismo" {{ request('tipo') == 'bautismo' ? 'selected' : '' }}>Bautismo</option>
                    <option value="matrimonio" {{ request('tipo') == 'matrimonio' ? 'selected' : '' }}>Matrimonio</option>
                    <option value="consagracion" {{ request('tipo') == 'consagracion' ? 'selected' : '' }}>Consagración</option>
                </select>
            </div>
            <div class="col-md-3">
                <input type="date" name="fecha" class="form-control" value="{{ request('fecha') }}">
            </div>
            <div class="col-md-12 mt-2">
                <button type="submit" class="btn btn-primary">
                    <i class="fas fa-search"></i> <!-- Icono de búsqueda -->
                </button>
                <a href="{{ route('certificados.index') }}" class="btn btn-secondary">
                    <i class="fas fa-times"></i> <!-- Icono de limpiar -->
                </a>
            </div>
        </div>
    </form>

    <!-- Tabla de certificados -->
    
    <table class="table table-striped mt-2">
        <thead style="background-color:#2f2bec">
            <tr>
                <th style="color:#fff">Tipo</th>
                <th style="color:#fff">Fecha</th>
                <th style="color:#fff">Iglesia</th>
                <th style="color:#fff">Folio</th>
                <th style="color:#fff">Estado de Pago</th>
                <th style="color:#fff">Acciones</th>
            </tr>
        </thead>
        <tbody>
            @foreach ($certificados as $certificado)
            <tr>
                <td>{{ ucfirst($certificado->tipo) }}</td>
                <td>
                    @if($certificado->tipo == 'matrimonio')
                        {{ $certificado->fecha_matrimonio ? \Carbon\Carbon::parse($certificado->fecha_matrimonio)->format('d/m/Y') : '-' }}
                    @else
                        {{ $certificado->fecha ? \Carbon\Carbon::parse($certificado->fecha)->format('d/m/Y') : '-' }}
                    @endif
                </td>
                <td>{{ $certificado->iglesia ? $certificado->iglesia->nombre : '-' }}</td>
                <td>{{ $certificado->folio ?? '-' }}</td>
                <td>
                    @if($certificado->tipo === 'bautismo')
                        <span class="badge bg-secondary">No aplicable</span>
                    @else
                        <span class="badge bg-{{ $certificado->pagoCompleto() ? 'success' : 'warning' }}">
                            {{ $certificado->pagoCompleto() ? 'Completo' : 'Incompleto' }}
                        </span>
                    @endif
                </td>
                <td>
                    <!-- Botón de Ver -->
                    <a href="{{ route('certificados.show', $certificado->id) }}" class="btn btn-info btn-sm">
                        <i class="fas fa-eye"></i> <!-- Icono de ver -->
                    </a>
                    <!-- Botón de Editar -->
                    <a href="{{ route('certificados.edit', $certificado->id) }}" class="btn btn-warning btn-sm">
                        <i class="fas fa-edit"></i> <!-- Icono de edición -->
                    </a>
                    <!-- Botón de Pagar -->
                    @if($certificado->tipo === 'consagracion' || $certificado->tipo === 'matrimonio')
                        @if(!$certificado->pagoCompleto())
                            <a href="{{ route('pagos.create', $certificado->id) }}" class="btn btn-primary btn-sm">
                                <i class="fas fa-credit-card"></i> <!-- Icono de pago -->
                            </a>
                        @endif
                    @endif
                    <!-- Botón de Descargar Certificado -->
                    @if(($certificado->tipo === 'bautismo') || ($certificado->pagoCompleto() && ($certificado->tipo === 'matrimonio' || $certificado->tipo === 'consagracion')))
                        <a href="{{ route('certificados.pdf', $certificado->id) }}" class="btn btn-danger btn-sm">
                            <i class="fas fa-file-download"></i> <!-- Icono de descarga -->
                        </a>
                    @endif
                </td>
            </tr>
            @endforeach
        </tbody>
    </table>
</div>
@endsection
