@extends('layouts.app')

@section('content')
<div class="container">
    <h3 class="text-center" style="color: #eeeff4;">Listado de Iglesias</h3>
    
    <!-- Botones de acciones -->
    <div class="d-flex justify-content-start mb-3">
        <a href="{{ route('iglesias.create') }}" class="btn btn-primary mr-2">
            <i class="fas fa-plus-circle"></i> Agregar Iglesia
        </a>
        <a href="{{ route('iglesias.index') }}" class="btn btn-primary">
            <i class="fas fa-eye"></i> Ver todas
        </a>
    </div>

    <!-- Mensaje de éxito -->
    @if ($message = Session::get('success'))
    <div class="alert alert-success">
        {{ $message }}
    </div>
    @endif

    <!-- Formulario de búsqueda y filtrado -->
    <form action="{{ route('iglesias.index') }}" method="GET" class="mb-4">
        <div class="row">
            <div class="col-md-4">
                <input type="text" name="nombre" class="form-control" placeholder="Buscar por nombre" value="{{ request('nombre') }}">
            </div>
            <div class="col-md-4">
                <select name="regional_id" class="form-control">
                    <option value="">Filtrar por Regional</option>
                    @foreach ($regionales as $regional)
                    <option value="{{ $regional->id }}" {{ request('regional_id') == $regional->id ? 'selected' : '' }}>
                        {{ $regional->nombre }}
                    </option>
                    @endforeach
                </select>
            </div>
            <div class="col-md-4">
                <button type="submit" class="btn btn-primary">
                    <i class="fas fa-search"></i> Buscar
                </button>
                <a href="{{ route('iglesias.index') }}" class="btn btn-secondary">
                    <i class="fas fa-times"></i> Limpiar
                </a>
            </div>
        </div>
    </form>

    <!-- Tabla de iglesias -->
    <div class="table-responsive">
        <table class="table table-striped table-hover">
            <thead style="background-color:#4b55ec;">
                <tr>
                    <th style="color:#fff;">Nombre</th>
                    <th style="color:#fff;">Ubicación</th>
                    <th style="color:#fff;">Regional</th>
                    <th style="color:#fff;">Estado</th>
                    <th style="color:#fff;">Acciones</th>
                </tr>
            </thead>
            <tbody>
                @foreach ($iglesias as $iglesia)
                <tr>
                    <td>{{ $iglesia->nombre }}</td>
                    <td>{{ $iglesia->ubicacion }}</td>
                    <td>{{ $iglesia->regional->nombre }}</td>
                    <td>
                        <span class="badge {{ $iglesia->estado ? 'bg-success' : 'bg-secondary' }}">
                            {{ $iglesia->estado ? 'Activo' : 'Inactivo' }}
                        </span>
                    </td>
                    <td>
                        <!-- Botón de editar -->
                        <a href="{{ route('iglesias.edit', $iglesia->id) }}" class="btn btn-warning btn-sm">
                            <i class="fas fa-edit"></i> <!-- Icono de edición -->
                        </a>
                        <!-- Botón de activar/desactivar -->
                        <form action="{{ route('iglesias.destroy', $iglesia->id) }}" method="POST" style="display:inline;">
                            @csrf
                            @method('DELETE')
                            <button type="submit" class="btn btn-danger btn-sm" onclick="return confirm('¿Estás seguro de querer cambiar el estado de esta iglesia?')">
                                <i class="fas {{ $iglesia->estado ? 'fa-ban' : 'fa-check-circle' }}"></i> <!-- Icono de activar/desactivar -->
                            </button>
                        </form>
                    </td>
                </tr>
                @endforeach
            </tbody>
        </table>
        {{ $iglesias->links() }}
    </div>
</div>
@endsection
