@extends('layouts.app')

@section('content')
<div class="container">
    <h3 class="text-center" style="color: #eeeff4;">Agregar Nuevo Miembro</h3>
    <form action="{{ route('miembros.store') }}" method="POST">
        @csrf
        <div class="form-group">
            <label for="nombre">Nombre</label>
            <input type="text" name="nombre" id="nombre" class="form-control" value="{{ old('nombre') }}" required>
            @error('nombre')
            <small class="text-danger">{{ $message }}</small>
            @enderror
        </div>
        <div class="form-group">
            <label for="apellidos">Apellidos</label>
            <input type="text" name="apellidos" id="apellidos" class="form-control" value="{{ old('apellidos') }}" required>
            @error('apellidos')
            <small class="text-danger">{{ $message }}</small>
            @enderror
        </div>
        <div class="form-group">
            <label for="carnet">Carnet</label>
            <div class="input-group">
                <input type="text" name="carnet" id="carnet" class="form-control" value="{{ old('carnet') }}" required>
                <input type="text" name="complemento" id="complemento" class="form-control" placeholder="Complemento" value="{{ old('complemento') }}">
            </div>
            @error('carnet')
            <small class="text-danger">{{ $message }}</small>
            @enderror
            @error('complemento')
            <small class="text-danger">{{ $message }}</small>
            @enderror
        </div>
        
        <div class="form-group">
            <label for="extension">Extensión</label>
            <select name="extension" id="extension" class="form-control">
                <option value="">Seleccione...</option>
                <option value="LP" {{ old('extension') == 'LP' ? 'selected' : '' }}>La Paz</option>
                <option value="CB" {{ old('extension') == 'CB' ? 'selected' : '' }}>Cochabamba</option>
                <option value="SC" {{ old('extension') == 'SC' ? 'selected' : '' }}>Santa Cruz</option>
                <option value="OR" {{ old('extension') == 'OR' ? 'selected' : '' }}>Oruro</option>
                <option value="PT" {{ old('extension') == 'PT' ? 'selected' : '' }}>Potosí</option>
                <option value="TJ" {{ old('extension') == 'TJ' ? 'selected' : '' }}>Tarija</option>
                <option value="BN" {{ old('extension') == 'BN' ? 'selected' : '' }}>Beni</option>
                <option value="PA" {{ old('extension') == 'PA' ? 'selected' : '' }}>Pando</option>
                <option value="CH" {{ old('extension') == 'CH' ? 'selected' : '' }}>Chuquisaca</option>
            </select>
            @error('extension')
            <small class="text-danger">{{ $message }}</small>
            @enderror
        </div>
        
        <div class="form-group">
            <label for="telefono">Teléfono</label>
            <input type="text" name="telefono" id="telefono" class="form-control" value="{{ old('telefono') }}">
            @error('telefono')
            <small class="text-danger">{{ $message }}</small>
            @enderror
        </div>
        <div class="form-group">
            <label for="correo">Correo</label>
            <input type="email" name="correo" id="correo" class="form-control" value="{{ old('correo') }}">
            @error('correo')
            <small class="text-danger">{{ $message }}</small>
            @enderror
        </div>
        <div class="form-group">
            <label for="direccion">Dirección</label>
            <input type="text" name="direccion" id="direccion" class="form-control" value="{{ old('direccion') }}">
            @error('direccion')
            <small class="text-danger">{{ $message }}</small>
            @enderror
        </div>
        <div class="form-group">
            <label for="fecha_de_nacimiento">Fecha de Nacimiento</label>
            <input type="date" name="fecha_de_nacimiento" id="fecha_de_nacimiento" class="form-control" value="{{ old('fecha_de_nacimiento') }}" required>
            @error('fecha_de_nacimiento')
            <small class="text-danger">{{ $message }}</small>
            @enderror
        </div>
        <div class="form-group">
            <label for="iglesia_id">Iglesia</label>
            <select name="iglesia_id" id="iglesia_id" class="form-control select2">
                <option value="">Seleccione una iglesia</option>
                @foreach($iglesias as $id => $nombre)
                    <option value="{{ $id }}" {{ old('iglesia_id') == $id ? 'selected' : '' }}>{{ $nombre }}</option>
                @endforeach
            </select>
            @error('iglesia_id')
            <small class="text-danger">{{ $message }}</small>
            @enderror
        </div>
        
        <button type="submit" class="btn btn-success mt-3">Guardar</button>
        <a href="{{ route('miembros.index') }}" class="btn btn-secondary mt-3">Cancelar</a>
    </form>
</div>

<!-- Agregar jQuery antes de Select2 -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-beta.1/dist/css/select2.min.css" rel="stylesheet" />
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-beta.1/dist/js/select2.min.js"></script>

<script>
    $(document).ready(function() {
        $('.select2').select2({
            placeholder: 'Seleccione una iglesia',
            allowClear: true
        });
    });

    // Restringir la entrada de caracteres en los campos
    document.getElementById('carnet').addEventListener('input', function (e) {
        this.value = this.value.replace(/[^0-9]/g, '');
    });

    document.getElementById('nombre').addEventListener('input', function (e) {
        this.value = this.value.replace(/[^a-zA-ZáéíóúÁÉÍÓÚ\s\']/g, '');
    });

    document.getElementById('apellidos').addEventListener('input', function (e) {
        this.value = this.value.replace(/[^a-zA-ZáéíóúÁÉÍÓÚ\s\']/g, '');
    });
</script>


@endsection
