@extends('layouts.app')

@section('content')
<div class="container">
    <h3 class="text-center mb-4" style="color: #eeeff4;">Listado de Certificados y Pagos</h3>

<!-- Formulario de búsqueda y filtro -->
<form action="{{ route('pagos.index') }}" method="GET" class="mb-4">
    <div class="row">
        <!-- Buscar por Número -->
        <div class="col-md-3">
            <input type="text" name="numero" class="form-control" placeholder="Buscar por número" value="{{ request('numero') }}">
        </div>

        <!-- Buscar por Folio -->
        <div class="col-md-3">
            <input type="text" name="folio" class="form-control" placeholder="Buscar por folio" value="{{ request('folio') }}">
        </div>

        <!-- Filtro por Fecha -->
        <div class="col-md-3">
            <input type="date" name="fecha_inicio" class="form-control" value="{{ request('fecha_inicio') }}" placeholder="Fecha inicio">
        </div>
        <div class="col-md-3">
            <input type="date" name="fecha_fin" class="form-control" value="{{ request('fecha_fin') }}" placeholder="Fecha fin">
        </div>

        <!-- Filtro por Estado de Pago -->
        <div class="col-md-3 mt-2">
            <select name="estado_pago" class="form-control">
                <option value="">Filtrar por estado de pago</option>
                <option value="completo" {{ request('estado_pago') == 'completo' ? 'selected' : '' }}>Completo</option>
                <option value="incompleto" {{ request('estado_pago') == 'incompleto' ? 'selected' : '' }}>Incompleto</option>
            </select>
        </div>

        <!-- Botones -->
        <div class="col-md-3 mt-2">
            <button type="submit" class="btn btn-primary w-100">Buscar</button>
        </div>

        <div class="col-md-3 mt-2">
            <a href="{{ route('pagos.index') }}" class="btn btn-secondary w-100">Ver todos los pagos</a>
        </div>
    </form>
        <div class="col-md-3 mt-2">
            <form action="{{ route('pagos.exportPdf') }}" method="GET">
                <!-- Filtros que se pasan a la exportación -->
                <input type="hidden" name="numero" value="{{ request('numero') }}">
                <input type="hidden" name="folio" value="{{ request('folio') }}">
                <input type="hidden" name="estado_pago" value="{{ request('estado_pago') }}">
                <input type="hidden" name="fecha_inicio" value="{{ request('fecha_inicio') }}">
                <input type="hidden" name="fecha_fin" value="{{ request('fecha_fin') }}">

                <button type="submit" class="btn btn-danger w-100">Exportar a PDF</button>
            </form>
        </div>
    </div>



    <!-- Resultados de búsqueda y filtros aplicados -->

    <div class="row">
        <!-- Certificados con Pagos Completos -->
        <div class="col-md-6">
            <h4 class="text-center mb-4">Certificados con Pagos Completos</h4>
            @forelse ($pagosCompletos as $certificado)
                <div class="card mb-5">
                    <div class="card-header">
                        <h5 class="mb-3 text-center">
                            <strong>Certificado:</strong> {{ $certificado->numero }} - 
                            <span class="text-capitalize">{{ $certificado->tipo }}</span>
                        </h5>
                        <div class="d-flex justify-content-between align-items-center">
                            <div class="me-4">
                                <p class="mb-1"><strong>Iglesia:</strong> {{ $certificado->iglesia->nombre ?? 'N/A' }}</p>
                                <p class="mb-1"><strong>Número:</strong> {{ $certificado->numero }}</p>
                                <p class="mb-1"><strong>Folio:</strong> {{ $certificado->folio }}</p>
                            </div>
                            <div>
                                <p class="mb-1">
                                    <strong>Estado del Pago:</strong> 
                                    <span class="badge bg-success">Completo</span>
                                </p>
                            </div>
                        </div>
                    </div>

                    <div class="card-body">
                        <h6 class="mb-3 text-center">Detalles del Pago:</h6>
                        <table class="table table-sm table-hover">
                            <thead class="thead-light">
                                <tr>
                                    <th>Monto a Pagar</th>
                                    <th>Monto Pagado</th>
                                    <th>Fecha de Pago</th>
                                    <th>Registrado por</th>
                                </tr>
                            </thead>
                            <tbody>
                                @foreach ($certificado->pagos as $pago)
                                    <tr>
                                        <td>{{ number_format($pago->monto_a_pagar, 2) }}</td>
                                        <td>{{ number_format($pago->monto_pagado, 2) }}</td>
                                        <td>{{ \Carbon\Carbon::parse($pago->fecha_de_pago)->subHours(4)->format('d/m/Y H:i:s') }}</td>
                                        <td>{{ $pago->usuario->name }}</td>
                                    </tr>
                                @endforeach
                            </tbody>
                        </table>
                       

                    </div>
                </div>
            @empty
                <div class="alert alert-info">No hay certificados con pagos completos.</div>
            @endforelse
        </div>

        <!-- Certificados con Pagos Incompletos -->
        <div class="col-md-6">
            <h4 class="text-center mb-4">Certificados con Pagos Incompletos</h4>
            @forelse ($pagosIncompletos as $certificado)
                <div class="card mb-5">
                    <div class="card-header">
                        <h5 class="mb-3 text-center">
                            <strong>Certificado:</strong> {{ $certificado->numero }} - 
                            <span class="text-capitalize">{{ $certificado->tipo }}</span>
                        </h5>
                        <div class="d-flex justify-content-between align-items-center">
                            <div class="me-4">
                                <p class="mb-1"><strong>Iglesia:</strong> {{ $certificado->iglesia->nombre ?? 'N/A' }}</p>
                                <p class="mb-1"><strong>Número:</strong> {{ $certificado->numero }}</p>
                                <p class="mb-1"><strong>Folio:</strong> {{ $certificado->folio }}</p>
                            </div>
                            <div>
                                <p class="mb-1">
                                    <strong>Estado del Pago:</strong> 
                                    <span class="badge bg-warning">Incompleto</span>
                                </p>
                            </div>
                        </div>
                    </div>

                    <div class="card-body">
                        <h6 class="mb-3 text-center">Detalles del Pago:</h6>
                        <table class="table table-sm table-hover">
                            <thead class="thead-light">
                                <tr>
                                    <th>Monto a Pagar</th>
                                    <th>Monto Pagado</th>
                                    <th>Fecha de Pago</th>
                                    <th>Registrado por</th>
                                </tr>
                            </thead>
                            <tbody>
                                @foreach ($certificado->pagos as $pago)
                                    <tr>
                                        <td>{{ number_format($pago->monto_a_pagar, 2) }}</td>
                                        <td>{{ number_format($pago->monto_pagado, 2) }}</td>
                                        <td>{{ \Carbon\Carbon::parse($pago->fecha_de_pago)->subHours(4)->format('d/m/Y H:i:s') }}</td>
                                        <td>{{ $pago->usuario->name }}</td>
                                    </tr>
                                @endforeach
                            </tbody>
                        </table>
                        
                    </div>
                </div>a
            @empty
                <div class="alert alert-info">No hay certificados con pagos incompletos.</div>
            @endforelse
        </div>
    </div>
</div>
@endsection
