@extends('layouts.app')

@section('content')
<div class="container">
    <h3 class="text-center text-primary mb-4">Reportes Detallados de Certificados</h3>

    <!-- Filtros avanzados -->
    <div class="card mb-4 shadow-sm">
        <div class="card-header bg-info text-white">Filtros de Reporte</div>
        <div class="card-body">
            <form method="GET" action="{{ route('reportes.certificados_detallados') }}" class="row">
                <div class="col-md-4 mb-3">
                    <label for="fecha_inicio" class="form-label">Fecha Inicio</label>
                    <input type="date" name="fecha_inicio" class="form-control" value="{{ request('fecha_inicio') }}">
                </div>
                <div class="col-md-4 mb-3">
                    <label for="fecha_fin" class="form-label">Fecha Fin</label>
                    <input type="date" name="fecha_fin" class="form-control" value="{{ request('fecha_fin') }}">
                </div>
                <div class="col-md-4 d-flex align-items-end">
                    <button type="submit" class="btn btn-primary w-100">Filtrar</button>
                </div>
            </form>
        </div>
    </div>

    <!-- Botones de acciones -->
    <div class="d-flex justify-content-end mb-3">
        <a href="{{ route('reportes.descargar', ['tipoReporte' => 'certificados_detallados', 'fecha_inicio' => request('fecha_inicio'), 'fecha_fin' => request('fecha_fin')]) }}" class="btn btn-secondary mr-2">Descargar PDF</a>
        <a href="{{ route('reportes.certificados_detallados') }}" class="btn btn-warning">Ver Todos</a>
    </div>

    <!-- Tablas de Certificados -->
    @php
        $sections = [
            ['title' => 'Certificados de Bautismo', 'data' => $certificadosBautismo, 'columns' => ['Nombre Miembro', 'Iglesia', 'Regional', 'Folio', 'Otorgado', 'Lugar', 'Fecha de Registro']],
            ['title' => 'Certificados de Matrimonio', 'data' => $certificadosMatrimonio, 'columns' => ['Señor', 'Señora', 'Iglesia', 'Regional', 'Notaría Nº', 'Libro Nº', 'Fecha de Matrimonio']],
            ['title' => 'Certificados de Consagración', 'data' => $certificadosConsagracion, 'columns' => ['Nombre Miembro', 'Iglesia', 'Regional', 'Folio', 'Padre', 'Madre', 'Fecha de Registro']]
        ];
    @endphp

    @foreach($sections as $section)
        <h4 class="text-info mt-4">{{ $section['title'] }}</h4>
        <div class="table-responsive mb-4 shadow-sm">
            <table class="table table-bordered table-hover">
                <thead class="thead-dark">
                    <tr>
                        @foreach($section['columns'] as $column)
                            <th>{{ $column }}</th>
                        @endforeach
                    </tr>
                </thead>
                <tbody>
                    @foreach($section['data'] as $certificado)
                        <tr>
                            <td>{{ $certificado->miembro ? $certificado->miembro->nombre . ' ' . $certificado->miembro->apellidos : '-' }}</td>
                            <td>{{ $certificado->iglesia ? $certificado->iglesia->nombre : '-' }}</td>
                            <td>{{ $certificado->iglesia && $certificado->iglesia->regional ? $certificado->iglesia->regional->nombre : '-' }}</td>
                            <td>{{ $certificado->folio ?? '-' }}</td>
                            <td>{{ $section['title'] === 'Certificados de Matrimonio' ? $certificado->notaria_numero ?? '-' : ($section['title'] === 'Certificados de Bautismo' ? $certificado->otorgado ?? '-' : $certificado->padre ?? '-') }}</td>
                            <td>{{ $section['title'] === 'Certificados de Matrimonio' ? $certificado->libro_numero ?? '-' : ($section['title'] === 'Certificados de Bautismo' ? $certificado->lugar ?? '-' : $certificado->madre ?? '-') }}</td>
                            <td>{{ $section['title'] === 'Certificados de Matrimonio' ? ($certificado->fecha_matrimonio ? \Carbon\Carbon::parse($certificado->fecha_matrimonio)->format('d/m/Y') : '-') : ($certificado->fecha ? \Carbon\Carbon::parse($certificado->fecha)->format('d/m/Y') : '-') }}</td>
                        </tr>
                    @endforeach
                </tbody>
            </table>
        </div>
    @endforeach
</div>
@endsection
