<!DOCTYPE html>
<html>
<head>
    <meta charset="UTF-8">
    <title>Reporte - Total de Certificados Emitidos</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            margin: 0;
            padding: 0;
            font-size: 12px;
            background-color: #f4f4f4;
        }
        h3 {
            color: #2F4F4F;
            text-align: center;
            margin-top: 20px;
        }
        .report-header {
            text-align: right;
            font-size: 12px;
            margin: 10px 20px;
            color: #555;
        }
        .report-container {
            width: 100%;
            margin: 0 auto;
            padding: 20px;
            border: 1px solid #ddd;
            background-color: #fff;
        }
        .report-table {
            width: 100%;
            border-collapse: collapse;
            margin-top: 20px;
            font-size: 12px;
        }
        .report-table th, .report-table td {
            border: 1px solid #ccc;
            padding: 8px;
            text-align: left;
        }
        .report-table th {
            background-color: #2F4F4F;
            color: white;
        }
        .total-row td {
            font-weight: bold;
            background-color: #f0f0f0;
        }
        .section-title {
            font-size: 14px;
            font-weight: bold;
            margin-top: 30px;
            color: #333;
            border-bottom: 1px solid #ccc;
            padding-bottom: 5px;
        }
        .total-general {
            font-size: 14px;
            font-weight: bold;
            text-align: right;
            margin-top: 20px;
        }
        .report-footer {
            text-align: center;
            font-size: 10px;
            margin-top: 40px;
            color: #888;
        }
        .logo { height: 60px; }
        .title { font-size: 20px; font-weight: bold; text-align: center; margin: 0 auto; }
    </style>
</head>
<body>

<div class="report-container">
    <div class="report-header">
        <img src="{{ public_path('img/logo.png') }}" alt="Logo" class="logo">
        <div class="title">Grupo Evangélico BETESDA</div>
        <div class="report-date">Fecha y Hora del Reporte: {{ \Carbon\Carbon::now()->subHours(4)->format('d/m/Y H:i:s') }}</div>
    </div>

    <!-- Cabecera del reporte -->
    <div class="report-header">
        Fecha y Hora del Reporte: {{ \Carbon\Carbon::now()->subHours(4)->format('d/m/Y H:i:s') }}
    </div>

    <!-- Título principal -->
    <h3>Total de Certificados Emitidos</h3>

    <!-- Tabla de certificados por tipo -->
    <h3>Certificados Emitidos por Tipo</h3>
    <table class="report-table">
        <thead>
            <tr>
                <th>Tipo de Certificado</th>
                <th>Total Emitido</th>
            </tr>
        </thead>
        <tbody>
            @php $totalGeneral = 0; @endphp
            @foreach($data['certificadosPorTipo'] as $certificado)
                <tr>
                    <td>{{ ucfirst($certificado->tipo) }}</td>
                    <td>{{ $certificado->total }}</td>
                </tr>
                @php $totalGeneral += $certificado->total; @endphp
            @endforeach
            <tr class="total-row">
                <td>Total General</td>
                <td>{{ $totalGeneral }}</td>
            </tr>
        </tbody>
    </table>

    <!-- Separador -->
    <hr>

    <!-- Certificados por Tipo e Iglesia -->
    <h3>Certificados por Tipo e Iglesia</h3>
    @php
        $iglesiasAgrupadas = $data['porTipoEIglesia']->groupBy('iglesia_nombre');
    @endphp

    @foreach($iglesiasAgrupadas as $iglesiaNombre => $certificados)
        <div class="section-title">Iglesia: {{ $iglesiaNombre ?? 'N/A' }}</div>
        <table class="report-table">
            <thead>
                <tr>
                    <th>Tipo de Certificado</th>
                    <th>Total Emitido</th>
                </tr>
            </thead>
            <tbody>
                @php $totalPorIglesia = 0; @endphp
                @foreach($certificados as $certificado)
                    <tr>
                        <td>{{ ucfirst($certificado->tipo) }}</td>
                        <td>{{ $certificado->total }}</td>
                    </tr>
                    @php $totalPorIglesia += $certificado->total; @endphp
                @endforeach
                <tr class="total-row">
                    <td>Total en {{ $iglesiaNombre }}</td>
                    <td>{{ $totalPorIglesia }}</td>
                </tr>
            </tbody>
        </table>
    @endforeach

    <!-- Separador -->
    <hr>

    <!-- Certificados por Tipo y Regional -->
    <h3>Certificados por Tipo y Regional</h3>
    @php
        $regionalesAgrupadas = $data['porRegional']->groupBy('regional_nombre');
    @endphp

    @foreach($regionalesAgrupadas as $regionalNombre => $certificados)
        <div class="section-title">Regional: {{ $regionalNombre ?? 'N/A' }}</div>
        <table class="report-table">
            <thead>
                <tr>
                    <th>Tipo de Certificado</th>
                    <th>Total Emitido</th>
                </tr>
            </thead>
            <tbody>
                @php $totalPorRegional = 0; @endphp
                @foreach($certificados as $certificado)
                    <tr>
                        <td>{{ ucfirst($certificado->tipo) }}</td>
                        <td>{{ $certificado->total }}</td>
                    </tr>
                    @php $totalPorRegional += $certificado->total; @endphp
                @endforeach
                <tr class="total-row">
                    <td>Total en {{ $regionalNombre }}</td>
                    <td>{{ $totalPorRegional }}</td>
                </tr>
            </tbody>
        </table>
    @endforeach

    <!-- Total General al final del reporte -->
    <div class="total-general">
        Total General de Certificados: {{ $totalGeneral }}
    </div>

    <!-- Pie de página del reporte -->
    <div class="report-footer">
        Reporte generado automáticamente por el sistema.
    </div>
</div>

</body>
</html>
